__version__ = "0.2.11"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(HEAD detached at v0.2.11)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '4a8b7cd828e57a2d3785ed2434a6f3622ab12811'
__git_head_subject__ = 'bump isolated python version'
__git_head_message__ = ''
__git_dirty_diff__ = ''
__git_commit_date__ = '2015-11-27 13:38:44'
